==> cpm-1.1.0.tar.gz: cpm-1.1.0/models/cpm_models.h <==
#ifndef CPM_MODELS_H_
#define CPM_MODELS_H_

/*!
 * \defgroup models Communication performance models
 * This module provide the following models:
 * - \ref hockney \latexonly\cite{Hockney1994}\endlatexonly
 * - \ref plogp \latexonly\cite{Kielmann2000}\endlatexonly
 * - \ref lmo \latexonly\cite{Lastovetsky2008ASoftwareTool}\endlatexonly
 * 
 * For each model, this module provides the following interface (\c X stands for the name of the model:
 * \c Hockney, \c PLogP or \c LMO):
 * - \code
struct X_model {
	CPM_predictor predictor;
	... // parameters
}
 * \endcode
 * is a data structure containing the parameters of the model and a set of the estimation functions
 * defined by \ref CPM_predictor.
 * - \code
void X_build(MPI_Comm, MPIB_msgset, MPIB_precision, int parallel, X_model**);
 * \endcode
 * is a function responsible for building the model with given precision and message sizes.
 * If the \c parallel argument is set to zero, the communication experiments will be performed
 * consequently, otherwise in parallel.
 * - \code
void X_read(FILE*, X_model**);
void X_write(FILE*, const X_model*);
 * \endcode
 * are functions for input/output of the model data.
 * 
 * This interface can be used directly in parallel applications.
 * It is also a basis for optimized implementations of MPI collective communication operations
 * (see \ref cpm_coll).
 * \{
 */
#ifdef __cplusplus
extern "C" {
#endif

/*!
 * An predictor of the communication execution time.
 * Contains a set of the predict functions:
 * - <code>double (*predict_p2p)(void* _this, int i, int j, int M)</code> is a function
 * predicting the execution time of the point-to-point communication operation,
 * where \c i and \c j are the indices of the processors, \c M is a message size.
 * - <code>double (*predict_Y)(void* _this, int M, int root, int size)</code> is a function
 * predicting the execution time of the algorithm of collective communication operation \c Y
 * (for example, \c Scatter_binomial).
 * The \c root parameter is significant for the collective operations with the root processor.
 * 
 * Each of the estimation functions includes a self pointer argument \c _this to be used
 * in the derived data structures (communication performance models).
 */
typedef struct CPM_predictor {
	/*!
	 * Predicts the execution time of the point-to-point communication
	 * \param _this a self pointer
	 * \param i an index of a processor involved in point-to-point communication
	 * \param j an index of a processor involved in point-to-point communication
	 * \param M a message size.
	 * \return predicted execution time
	 */
	double (*predict_p2p)(void* _this, int i, int j, int M);
} CPM_predictor;

/*!
 * Invalid model instance. A return error code to be used in the model-based implementations of
 * collective communication operations.
 */
#define CPM_ERR_MODEL MPI_ERR_LASTCODE + 100

#ifdef __cplusplus
}
#endif

/*!
 * \}
 */

#endif /*CPM_MODELS_H_*/

==> cpm-1.2.0.tar.gz: cpm-1.2.0/models/cpm_models.h <==
#ifndef CPM_MODELS_H_
#define CPM_MODELS_H_

/*!
 * \defgroup models Communication performance models
 * This module provide the following models:
 * - \ref lininterp \latexonly\cite{Hockney1994}\endlatexonly
 * - \ref hockney \latexonly\cite{Hockney1994}\endlatexonly
 * - \ref plogp \latexonly\cite{Kielmann2000}\endlatexonly
 * - \ref lmo \latexonly\cite{Lastovetsky2008ASoftwareTool}\endlatexonly
 * 
 * For each model, this module provides the following interface (\c X stands for the name of the model:
 * \c Hockney, \c PLogP or \c LMO):
 * - \code
struct X_model {
	CPM_predictor predictor;
	... // parameters
}
 * \endcode
 * is a data structure containing the parameters of the model and a set of the estimation functions
 * defined by \ref CPM_predictor.
 * - \code
X_model* X_alloc(int);
void X_free(X_model*);
 * \endcode
 * are functions to allocate/free the model data.
 * - \code
void X_estimate(MPI_Comm, MPIB_msgset, MPIB_precision, int parallel, X_model**);
 * \endcode
 * is a function responsible for estimation of the model with given precision and message sizes.
 * If the \c parallel argument is set to zero, the communication experiments will be performed
 * consequently, otherwise in parallel.
 * - \code
void X_read(FILE*, X_model**);
void X_write(FILE*, const X_model*);
 * \endcode
 * are functions for input/output of the model data.
 * 
 * This interface can be used directly in parallel applications.
 * It is also a basis for optimized implementations of MPI collective communication operations
 * (see \ref cpm_coll).
 */

#include "lininterp.h"
#include "hockney.h"
#include "plogp.h"
#include "lmo.h"

#endif /*CPM_MODELS_H_*/
